# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/network/dns_resolver/cares/v3/cares_dns_resolver.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/network/dns_resolver/cares/v3/cares_dns_resolver.proto\x12.envoy.extensions.network.dns_resolver.cares.v3\x1a\"envoy/config/core/v3/address.proto\x1a#envoy/config/core/v3/resolver.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9a\x02\n\x16\x43\x61resDnsResolverConfig\x12:\n\tresolvers\x18\x01 \x03(\x0b\x32\x1d.envoy.config.core.v3.AddressB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12!\n\x19use_resolvers_as_fallback\x18\x03 \x01(\x08\x12\"\n\x1a\x66ilter_unroutable_families\x18\x04 \x01(\x08\x12\x46\n\x14\x64ns_resolver_options\x18\x02 \x01(\x0b\x32(.envoy.config.core.v3.DnsResolverOptions\x12\x35\n\x0fudp_max_queries\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xbe\x01\n<io.envoyproxy.envoy.extensions.network.dns_resolver.cares.v3B\x15\x43\x61resDnsResolverProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/network/dns_resolver/cares/v3;caresv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.network.dns_resolver.cares.v3.cares_dns_resolver_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.extensions.network.dns_resolver.cares.v3B\025CaresDnsResolverProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/network/dns_resolver/cares/v3;caresv3\272\200\310\321\006\002\020\002'
  _CARESDNSRESOLVERCONFIG.fields_by_name['resolvers']._options = None
  _CARESDNSRESOLVERCONFIG.fields_by_name['resolvers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_CARESDNSRESOLVERCONFIG']._serialized_start=285
  _globals['_CARESDNSRESOLVERCONFIG']._serialized_end=567
# @@protoc_insertion_point(module_scope)
